@@ -3,7 +3,7 @@ package Data::Format::Pretty::HTML;
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Data::Format::Pretty::Console 0.24;
 use HTML::Entities;
@@ -15,7 +15,7 @@ require Exporter;
 our @ISA = qw(Exporter Data::Format::Pretty::Console);
 our @EXPORT_OK = qw(format_pretty);
 
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 sub content_type { "text/html" }
 
@@ -138,7 +138,7 @@ Data::Format::Pretty::HTML - Pretty-print data structure for HTML output
 
 =head1 VERSION
 
-This document describes version 0.09 of Data::Format::Pretty::HTML (from Perl distribution Data-Format-Pretty-HTML), released on 2014-07-24.
+This document describes version 0.10 of Data::Format::Pretty::HTML (from Perl distribution Data-Format-Pretty-HTML), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -249,8 +249,6 @@ Differences with Data::Format::Pretty::Console:
 
 =back
 
-This module uses L<Log::Any> for logging.
-
 =for Pod::Coverage new
 
 =head1 FUNCTIONS
@@ -294,11 +292,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
